[Current]
^^^^^^^^^

-  `2c1fb03 <../../commit/2c1fb03>`__ - **(Sagar Dwibhashyam)** Updated
   changelog
-  `40e454c <../../commit/40e454c>`__ - **(Sagar Dwibhashyam)** Updated
   version with few bug fixes

0.9.8
^^^^^

-  `a97a171 <../../commit/a97a171>`__ - **(Sagar V Dwibhashyam)**
   Updated Documentation
-  `0d961d0 <../../commit/0d961d0>`__ - **(Sagar V Dwibhashyam)** Fixed
   bugs related to progress bars
-  `60344b0 <../../commit/60344b0>`__ - **(Sagar V Dwibhashyam)** Fixed
   a small bug in kwargs\_helper
-  `39c0109 <../../commit/39c0109>`__ - **(Sagar V Dwibhashyam)**
   Updated the version in yad file
-  `6407159 <../../commit/6407159>`__ - **(Sagar V Dwibhashyam)** Solved
   some issues with the new features
-  `a14aa0e <../../commit/a14aa0e>`__ - **(Sagar V Dwibhashyam)**
   Updated info in Readme
-  `a790850 <../../commit/a790850>`__ - **(Sagar V Dwibhashyam)**
   Updated version
-  `4e92058 <../../commit/4e92058>`__ - **(Sagar V Dwibhashyam)**
   Updated Changelog. #vpat++
-  `cb738c8 <../../commit/cb738c8>`__ - **(Sagar V Dwibhashyam)** Added
   new features. #vpat++
-  `9b1984c <../../commit/9b1984c>`__ - **(Sagar DV)** Fixed information
   in readme.rst
-  `a110b8e <../../commit/a110b8e>`__ - **(Sagar DV)** Reorganized
   files.
-  `31ea3ef <../../commit/31ea3ef>`__ - **(Sagar DV)** Reorganized files

0.9.5
^^^^^

-  `d30a994 <../../commit/d30a994>`__ - **(Sagar DV)** version update:
   0.9.5
-  `ecd43e6 <../../commit/ecd43e6>`__ - **(Sagar DV)** Version 0.9.5 is
   ready. #vpat++
-  `7a62d9c <../../commit/7a62d9c>`__ - **(Sagar DV)** Added the Html
   dialog. The functionality for the html dialog has been added but
   wasnt able to test it as the original yad program was giving
   segmentation faults.
-  `fd85d34 <../../commit/fd85d34>`__ - **(Sagar DV)** Updated yad.py
   with additional arguments. Various dialogs have been updated with
   additional arguments. Check the src.
-  `3c11fca <../../commit/3c11fca>`__ - **(Sagar DV)** Fixed setup.py

0.9.4
^^^^^

-  `7fb6776 <../../commit/7fb6776>`__ - **(Sagar DV)** version update:
   0.9.4
-  `f565d9a <../../commit/f565d9a>`__ - **(Sagar DV)** Changed License
   to GPL3. #vpat++

0.9.3-r
^^^^^^^

-  `c927f3e <../../commit/c927f3e>`__ - **(dvenkatsagar)** Update
   changelogs. and uploading to pypi completed

0.9.3
^^^^^

-  `418d2ec <../../commit/418d2ec>`__ - **(dvenkatsagar)** version
   update: 0.9.3
-  `6d245a7 <../../commit/6d245a7>`__ - **(dvenkatsagar)** Updating
   Version and Adding to pypi. #vpat++
-  `c7b7dac <../../commit/c7b7dac>`__ - **(dvenkatsagar)** Fixed few
   bugs in the example gdie
-  `39c7682 <../../commit/39c7682>`__ - **(dvenkatsagar)** Fixed the
   README.rst
-  `f316347 <../../commit/f316347>`__ - **(dvenkatsagar)** Fixed gdie
-  `8e04657 <../../commit/8e04657>`__ - **(dvenkatsagar)** Fixed
   Directory structure
-  `1740e47 <../../commit/1740e47>`__ - **(dvenkatsagar)** Fixed bug in
   gdie
-  `72e7c33 <../../commit/72e7c33>`__ - **(dvenkatsagar)** update
   changelog

Conflicts: CHANGELOG.rst

-  `14e59ac <../../commit/14e59ac>`__ - **(dvenkatsagar)** Made some
   changes
-  `235a49d <../../commit/235a49d>`__ - **(dvenkatsagar)** Fixed
   changelog

0.9.2
^^^^^

-  `0120e81 <../../commit/0120e81>`__ - **(dvenkatsagar)** version
   update: 0.9.2
-  `97d09de <../../commit/97d09de>`__ - **(dvenkatsagar)** Added an
   Example Application. vpat++
-  `552874a <../../commit/552874a>`__ - **(dvenkatsagar)** Uploaded
   files to pypi

0.9.1-r
^^^^^^^

-  `76c1947 <../../commit/76c1947>`__ - **(dvenkatsagar)** update
   changelog. releasing 0.9.1
-  `b7bd707 <../../commit/b7bd707>`__ - **(dvenkatsagar)** Removed Apps
   and added them to a seperate repository. Will be coming soon.
-  `cf7e99c <../../commit/cf7e99c>`__ - **(dvenkatsagar)** updated
   setup.py version
-  `591ed55 <../../commit/591ed55>`__ - **(dvenkatsagar)** Fixed small
   bugs
-  `f006c80 <../../commit/f006c80>`__ - **(dvenkatsagar)** updated
   documentation

0.9.1
^^^^^

-  `0357e5e <../../commit/0357e5e>`__ - **(dvenkatsagar)** version
   update: 0.9.1
-  `63a9ee5 <../../commit/63a9ee5>`__ - **(dvenkatsagar)** Added general
   multi-button support. Added example applications. Update program
   documentation. #vpat++
-  `c17f6f2 <../../commit/c17f6f2>`__ - **(dvenkatsagar)** FIxed some
   issues with the Progress bars
-  `2633601 <../../commit/2633601>`__ - **(dvenkatsagar)** Fixed Version
   Numbers
-  `8153d0b <../../commit/8153d0b>`__ - **(dvenkatsagar)** version
   update: 0.9.3
-  `b90faf3 <../../commit/b90faf3>`__ - **(dvenkatsagar)** Fixed
   CHANGELOG output. #vpat++
-  `29e95a5 <../../commit/29e95a5>`__ - **(dvenkatsagar)** Fixed the
   changelog to changelog.md

0.9.0
^^^^^

-  `9240e3e <../../commit/9240e3e>`__ - **(dvenkatsagar)** Fixed
   Changelog
-  `a07111b <../../commit/a07111b>`__ - **(dvenkatsagar)** Updated
   setup.py
-  `0e5cdd2 <../../commit/0e5cdd2>`__ - **(dvenkatsagar)** Updated
   setup.py
-  `6d4037b <../../commit/6d4037b>`__ - **(dvenkatsagar)** made changes
   to README.rst
-  `ec525c4 <../../commit/ec525c4>`__ - **(dvenkatsagar)** Made some
   final Fixes
-  `642ef0a <../../commit/642ef0a>`__ - **(dvenkatsagar)** Modified
   changelog
-  `e3aa610 <../../commit/e3aa610>`__ - **(dvenkatsagar)** made
   release-0.9.0 for deployment
-  `8699517 <../../commit/8699517>`__ - **(dvenkatsagar)** version
   update: 0.9.0 Reintroduced subprocess for progress bars. Added
   python2 support. Added Notebook functionality. Modified docs. Added
   Read Me Files. Added Setup.py files Modified Documentation. Changed
   License files. version update: 0.8.0 Switched to pexpect. Remove
   Subprocess entirely. Fixed some issues regarding the call back
   functions. version update: 0.7.7 coverted most of code for pexpect.
   Still some more to do. version update: 0.7.6 modified the list listen
   functionality. Initial commit

